@@ -2,7 +2,7 @@
 #
 # Clean up users older than N days from the attic
 # Author: Finn-Arne Johansen <faj@bzz.no>
-# $Id: ldap-user-clean-attic.sh,v 1.2 2004/06/16 21:01:59 finnarne-guest Exp $
+# $Id: ldap-user-clean-attic.sh 67719 2010-08-03 19:54:05Z pere $
 
 # Show how this thing is used
 
@@ -28,25 +28,27 @@ if [ $? -ne 0 ] ; then
   exit 9
 fi
 
+# Locate the LDAP admin DN
+admindn=$(ldapsearch -x "(&(cn=admin)(objectClass=simpleSecurityObject))" 2>/dev/null | perl -p0e 's/\n //g' | awk '/^dn: / {print $2}')
+
+LDAPBASE="$(debian-edu-ldapserver -b)"
+
 TMPFILE=/tmp/$(basename $0).$$
 
 touch $TMPFILE
 chmod 0600 $TMPFILE
 chown 0:0 $TMPFILE
 
-ldapsearch -LLL -H ldaps://ldap -x -b "ou=Attic,dc=skole,dc=skolelinux,dc=no" \
+ldapsearch -LLL -x -b "ou=attic,$LDAPBASE" \
   "(&(uid=*)(modifyTimestamp<=$OLDERTHAN))" homeDirectory > $TMPFILE
 
 if ! grep -q "^dn:" $TMPFILE ; then 
   echo "Sorry, Nothing to delete, exiting"
 else
-  grep "^dn:" $TMPFILE | cut -f2 -d: | \
-    ldapdelete -H ldaps://ldap -x \
-               -D "cn=admin,ou=People,dc=skole,dc=skolelinux,dc=no" -W
+  grep "^dn:" $TMPFILE | cut -f2 -d: | ldapdelete -ZZ -x -D "$admindn" -W
   for EACH in $(grep "^homeDirectory:" $TMPFILE | cut -f2- -d:) ; do 
     rm -rf $EACH
   done 
 fi
 
 rm -rf $TMPFILE
-
