@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# $Id: logoutkill.sh 426 2004-04-25 21:38:13Z pere $
+# $Id: logoutkill.sh 42155 2008-07-02 12:54:32Z holger $
 # This script could be run from /etc/kde2/kdm/Xreset by adding the line 
 # '/usr/share/debian-edu-config/tools/logoutkill.sh $USER'
 # right before the line 
@@ -10,10 +10,6 @@
 KEEPONES="root USER daemon"
 USERLIMIT=10000
 
-if [ -f /etc/skolelinux/logoutkill.conf ] ; then 
-  mv /etc/skolelinux/logoutkill.conf /etc/debian-edu/logoutkill.conf
-fi 
-
 if [ -f /etc/debian-edu/logoutkill.conf ] ; then 
   . /etc/debian-edu/logoutkill.conf
 fi 
