@@ -1,16 +1,11 @@
 #!/bin/bash
 
-# $Id: nightkill.sh 418 2004-04-25 19:56:24Z pere $
+# $Id: nightkill.sh 42155 2008-07-02 12:54:32Z holger $
 # This script could be run every night, to kill stray processes. 
 
 KEEPONES="root USER daemon"
 USERLIMIT=10000
 
-# New location for config file [pere 2004-04-25]
-if [ -f /etc/skolelinux/nightkill.conf ] ; then 
-  mv /etc/skolelinux/nightkill.conf /etc/debian-edu/nightkill.conf
-fi
-
 if [ -f /etc/debian-edu/nightkill.conf ] ; then 
   . /etc/debian-edu/nightkill.conf
 fi 
@@ -20,14 +15,14 @@ for EVERY in $KEEPONES ; do
 done
 
 
-ps auxw | grep -vE $KEEP | \
+ps hauxwn | \
   while read PUSER PID NULL ; do 
-    [ $(id -u $PUSER) -ge $USERLIMIT ] && kill $PID ; 
+    [ $PUSER -ge $USERLIMIT ] && kill $PID >& /dev/null
   done
 
 sleep 10
   
-ps auxw | grep -vE $KEEP | \
+ps hauxwn  | \
   while read PUSER PID NULL ; do 
-    [ $(id -u $PUSER) -ge $USERLIMIT ] && kill -9 $PID ; 
+    [ $PUSER -ge $USERLIMIT ] && kill -9 $PID >& /dev/null 
   done
